@@ -6,7 +6,7 @@ use 5.008001;
 use base 'Alien::Base2';
 
 # ABSTRACT: Build and make available bz2
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 sub alien_helper
@@ -16,6 +16,13 @@ sub alien_helper
   };
 }
 
+# TODO: this should eventually be correctly handled by
+# Alien::Build
+sub config {
+  my($class, $key) = @_;
+  return 'bz2' if $key eq 'name' || $key eq 'ffi_name';
+  return $class->SUPER::config($key);
+}
 
 
 1;
@@ -32,7 +39,7 @@ Alien::Libbz2 - Build and make available bz2
 
 =head1 VERSION
 
-version 0.08
+version 0.18
 
 =head1 SYNOPSIS
 
